pub struct Instrumented<T> { /* private fields */ }Expand description
A future, stream, sink, or executor that has been instrumented with a tracing span.
Implementations
Sourceimpl Instrumented<Runtime>
impl Instrumented<Runtime>
Sourcepub fn spawn<F>(&mut self, future: F) -> &mut Self
pub fn spawn<F>(&mut self, future: F) -> &mut Self
Spawn an instrumented future onto the Tokio runtime.
This spawns the given future onto the runtime’s executor, usually a thread pool. The thread pool is then responsible for polling the future until it completes.
This method simply wraps a call to tokio::runtime::Runtime::spawn,
instrumenting the spawned future beforehand.
Sourcepub fn block_on<F, R, E>(&mut self, future: F) -> Result<R, E>
pub fn block_on<F, R, E>(&mut self, future: F) -> Result<R, E>
Run an instrumented future to completion on the Tokio runtime.
This runs the given future on the runtime, blocking until it is complete, and yielding its resolved result. Any tasks or timers which the future spawns internally will be executed on the runtime.
This method should not be called from an asynchronous context.
This method simply wraps a call to tokio::runtime::Runtime::block_on,
instrumenting the spawned future beforehand.
Panics
This function panics if the executor is at capacity, if the provided future panics, or if called within an asynchronous execution context.
Sourcepub fn executor(&self) -> Instrumented<TaskExecutor> ⓘ
pub fn executor(&self) -> Instrumented<TaskExecutor> ⓘ
Return an instrumented handle to the runtime’s executor.
The returned handle can be used to spawn tasks that run on this runtime.
The instrumented handle functions identically to a
tokio::runtime::TaskExecutor, but instruments the spawned
futures prior to spawning them.
Sourceimpl Instrumented<Runtime>
impl Instrumented<Runtime>
Sourcepub fn spawn<F>(&mut self, future: F) -> &mut Self
pub fn spawn<F>(&mut self, future: F) -> &mut Self
Spawn an instrumented future onto the single-threaded Tokio runtime.
This method simply wraps a call to current_thread::Runtime::spawn,
instrumenting the spawned future beforehand.
Sourcepub fn block_on<F, R, E>(&mut self, future: F) -> Result<R, E>where
F: 'static + Future<Item = R, Error = E>,
R: 'static,
E: 'static,
pub fn block_on<F, R, E>(&mut self, future: F) -> Result<R, E>where
F: 'static + Future<Item = R, Error = E>,
R: 'static,
E: 'static,
Instruments and runs the provided future, blocking the current thread until the future completes.
This function can be used to synchronously block the current thread
until the provided future has resolved either successfully or with an
error. The result of the future is then returned from this function
call.
Note that this function will also execute any spawned futures on the
current thread, but will not block until these other spawned futures
have completed. Once the function returns, any uncompleted futures
remain pending in the Runtime instance. These futures will not run
until block_on or run is called again.
The caller is responsible for ensuring that other spawned futures
complete execution by calling block_on or run.
This method simply wraps a call to current_thread::Runtime::block_on,
instrumenting the spawned future beforehand.
Panics
This function panics if the executor is at capacity, if the provided future panics, or if called within an asynchronous execution context.
Sourcepub fn handle(&self) -> Instrumented<Handle> ⓘ
pub fn handle(&self) -> Instrumented<Handle> ⓘ
Get a new instrumented handle to spawn futures on the single-threaded Tokio runtime
Different to the runtime itself, the handle can be sent to different threads.
The instrumented handle functions identically to a
tokio::runtime::current_thread::Handle, but instruments the spawned
futures prior to spawning them.
Sourceimpl<T> Instrumented<T>
impl<T> Instrumented<T>
Sourcepub fn span_mut(&mut self) -> &mut Span
pub fn span_mut(&mut self) -> &mut Span
Mutably borrows the Span that this type is instrumented by.
Sourcepub fn inner_pin_ref(self: Pin<&Self>) -> Pin<&T>
Available on crate feature std-future only.
pub fn inner_pin_ref(self: Pin<&Self>) -> Pin<&T>
std-future only.Get a pinned reference to the wrapped type.
Sourcepub fn inner_pin_mut(self: Pin<&mut Self>) -> Pin<&mut T>
Available on crate feature std-future only.
pub fn inner_pin_mut(self: Pin<&mut Self>) -> Pin<&mut T>
std-future only.Get a pinned mutable reference to the wrapped type.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the Instrumented, returning the wrapped type.
Note that this drops the span.